import React, { Component } from 'react';
import { Flex, NavBar, List, WingBlank, Toast } from 'antd-mobile';
import { OrderItem } from '@/common/index';
import { Link } from 'react-router-dom';
import { http, api } from "@/utils";

import "./order.scss"

const Item = List.Item;

const mockData = [
  {
    title: '三月面试求职班',
    imgUrl: 'https://julyedu-img-public.oss-cn-beijing.aliyuncs.com/Public/Image/4c5ccac604.jpg',
    content: '涵盖ML主流算法及其应用-文字超过一行换行然后呢再多呢是不是就出省略号了',
    newprice: '980',
    price: '1280',
    id: '110'
  },
  {
    title: '三月面试求职班',
    imgUrl: 'https://julyedu-img-public.oss-cn-beijing.aliyuncs.com/Public/Image/4c5ccac604.jpg',
    content: '涵盖ML主流算法及其应用-文字超过一行换行',
    newprice: '980',
    price: '1280',
    id: '110'
  },
  {
    title: '三月面试求职班',
    imgUrl: 'https://julyedu-img-public.oss-cn-beijing.aliyuncs.com/Public/Image/4c5ccac604.jpg',
    content: '涵盖ML主流算法及其应用-文字超过一行换行',
    newprice: '980',
    price: '1280',
    id: '110'
  }
]


function OrderList(props) {
  const listData = props.list;
  return (
    <div>
      {
        listData.map((item, index) => {
          const Info = (
            <div className="order-info">
              <p className='order-title' style={{ overflow: 'hidden', textOverflow: 'ellipsis', whiteSpace: 'nowrap' }}>{item.course_title}</p>
              <p className='order-content' style={{ WebkitBoxOrient: 'vertical', WebkitLineClamp: '2', wordBreak: 'break-all', overflow: 'hidden', textOverflow: 'ellipsis', display: '-webkit-box' }}>{item.simpledescription}</p>
              <p className='order-des'>
                <span className='order-newprice'>¥{item.price0}</span>
                <span className='order-price'>¥{item.price1}</span>
              </p>
            </div>
          )

          return (
            <OrderItem {...item} key={index} info={Info}>
              <div className="order-prefer">
                <List key={index}>
                  <Item
                    arrow="horizontal"
                    onClick={() => { }}
                  >
                    <Link to='/coupons'>
                      <Flex justify='between'>
                        <span>优惠券</span>
                        <span>无</span>
                      </Flex>
                    </Link>
                  </Item>
                </List>
              </div>
            </OrderItem>
          )
        })
      }
    </div>
  );
}

class Order extends Component {
  constructor(props) {
    super(props);
    this.state = {
      perfect: this.props.location.state,
      user_account: 0.00,
      total_sale: 0.00,
      discount: 0.00,
      useBalance: false,
      orderList: [],
    }
  }
  // 提交订单
  submitOrder = () => {
    const {
      perfect,
      total,
      discount
    } = this.state;
    if (!perfect) {
      Toast.info('请完善报名信息！');
    }
  }
  // 使用余额
  useBalance = () => {
    this.setState((prevState) => ({
      useBalance: !prevState.useBalance
    }));
    this.computedMoney();
  }
  // 计算金额、优惠金额、优惠券等
  computedMoney = () => {

  };
  // 展示余额抵扣规则
  showInfo = () => {

  };
  componentDidMount() {
    http.get(`${api.home}/m/order/preorder`).then((res) => {
      if (res.code !== 200) {
        return;
      }
      const { course, total_sale, user_account, user_info } = res.data.data;
      console.log(course);
      this.setState({
        perfect: user_info,
        orderList: course
      });
    })

    // // 获取报名信息 获取课程列表 获取用户账户余额
    // Promise.race([http.get(), http.get(), http.get()]).then(res=>{

    // });
  };
  render() {
    const {
      perfect,
      user_account,
      total_sale,
      discount,
      useBalance,
      orderList,
    } = this.state;

    return (
      <div className="order-wrapper">
        <Flex>
          <Flex.Item>
            <NavBar
              style={{ "height": "44px" }}
              className="order-tab"
              mode="light"
              icon={<i className="iconfont iconiconfront-68"></i>}
            >
              课程报名
                </NavBar>
            {
              !this.state.perfect &&
              <Link to='/orderinfo' className="order-information">
                <i className="iconfont iconiconfront-6 order-addsize"></i>
                <div className="order-infotext">完善报名信息</div>
                <i className="iconfont iconiconfront-70 order-next"></i>
              </Link>
            }
            {
              this.state.perfect &&
              <div className="order-information2">
                <WingBlank>
                  <Flex align='center' justify='between' style={{ height: '80px' }}>
                    <i className="iconfont iconiconfront-20 user-icon"></i>

                    <Flex direction='column' justify='between' align='start' className="order-cell">
                      <div className="name">{`姓名：${perfect.real_name}`}</div>
                      <div>{`电话：${perfect.cellphone}`}</div>
                    </Flex>

                    <Flex align='start' className="order-cell">
                      <div>{`QQ：${perfect.qq}`}</div>
                    </Flex>

                  </Flex>
                </WingBlank>
              </div>
            }
            <div className="order-list">
              <OrderList list={orderList} />
            </div>
            <div className="order-balance">
              <List>
                <Item
                  className="order-prefer-text"
                >
                  <Flex justify='between'>
                    <Flex align='center'>
                      <span>余额抵扣</span>
                      <span className="order-balanceprice"> (账户余额: <i className="order-money">{`${user_account}元`}</i>)</span>
                      <i className="iconfont iconiconfront-22" onClick={this.showInfo}></i>
                    </Flex>
                    {
                      useBalance ? (
                        <div>
                          <span style={{ color: '#FF2121', fontSize: '15px', marginRight: "6px" }}>{`-${user_account}`}</span>
                          <i className="iconfont icondanseshixintubiao-5" onClick={this.useBalance}></i>
                        </div>
                      ) : (
                        <i className="iconfont iconiconfront-3" onClick={this.useBalance}></i>
                      )
                    }
                  </Flex>
                </Item>
              </List>
            </div>
            <div className="order-bar">
              <div className="order-course">
                <span className="order-course-text">{`${orderList.length}门课程`}</span>
              </div>
              <div className="order-bar-text">
                <div className="order-amount">
                  <span className="order-amount-title">合计:</span>
                  <span className="order-amount-price">{`￥${total_sale}`}</span>
                </div>
                <div className="order-preprice">
                  <span className="order-preprice-title">已优惠:</span>
                  <span className="order-preprice-price">{`¥${discount}`}</span>
                </div>
              </div>
              {
                perfect ? (

                  <button type="button" className="order-button has-info">
                    <span className="order-button-text" onClick={this.submitOrder}>提交订单</span>
                  </button>
                ) : (

                    <button type="button" className="order-button">
                      <span className="order-button-text" onClick={this.submitOrder}>提交订单</span>
                    </button>
                  )
              }
            </div>
          </Flex.Item>
        </Flex>
      </div>

    )
  }

}

export default Order;